==> haskell-binary-orphans-1.0.5-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-orphans
version:              1.0.5
visibility:           public
id:                   binary-orphans-1.0.5-DD2YgVARNSj3onMbvZzsR
key:                  binary-orphans-1.0.5-DD2YgVARNSj3onMbvZzsR
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Compatibility package for binary; provides instances
description:
    This package provides instances defined in later versions of @binary@ package

    Prior version 1 this packages provided instances for other packages.
    That functionality is moved to [binary-instances](https://hackage.haskell.org/package/binary-instances) package.

category:             Data, Binary, Parsing, Compatibility
abi:                  8a7dedeedd862da2c24994b3333b43dd
exposed:              True
exposed-modules:      Data.Binary.Orphans
import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-orphans-1.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-orphans-1.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-orphans-1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-orphans
hs-libraries:         HSbinary-orphans-1.0.5-DD2YgVARNSj3onMbvZzsR
depends:              base-4.17.2.1 binary-0.8.9.1
haddock-interfaces:
    /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock

haddock-html:         /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-orphans-1.0.5-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-orphans
version:              1.0.5
visibility:           public
id:                   binary-orphans-1.0.5-A9IdD2cMt9i6xPeHB5Bvx4
key:                  binary-orphans-1.0.5-A9IdD2cMt9i6xPeHB5Bvx4
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Compatibility package for binary; provides instances
description:
    This package provides instances defined in later versions of @binary@ package

    Prior version 1 this packages provided instances for other packages.
    That functionality is moved to [binary-instances](https://hackage.haskell.org/package/binary-instances) package.

category:             Data, Binary, Parsing, Compatibility
abi:                  cc2ee5ee9a6e64f2ba39d84138c7383f
exposed:              True
exposed-modules:      Data.Binary.Orphans
import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-orphans-1.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-orphans-1.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-orphans-1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-orphans
hs-libraries:         HSbinary-orphans-1.0.5-A9IdD2cMt9i6xPeHB5Bvx4
depends:              base-4.17.2.1 binary-0.8.9.1
haddock-interfaces:
    /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock

haddock-html:         /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
